/**************************
	Google Spreadsheets
	By Neo101
	Version 1.0.1
**************************/


var SECURITY_ID = max_security_id
var PLUGIN_NAME = 'Google Spreadsheets'

var firstRun = MaxLib.checkSettingsFile()
if(firstRun == true){
	var showSettings = true
} else {
	var showSettings = false
}


var settings = {
	emailAddress : decodeURIComponent( decodeTxt( MaxLib.readSetting('EmailAddress') ) ),
	password : decodeTxt( MaxLib.readSetting('Password') ),
	authKey : decodeTxt( MaxLib.readSetting('authKey') ),

	maxNumberOfSpreadsheets : MaxLib.readSetting('maxNumberOfSpreadsheets')
}


if(settings.emailAddress == '' || settings.password == ''){
	showSettings = true
}

if(settings.emailAddress != '' && settings.emailAddress.search(/@/) == -1){
	settings.emailAddress = settings.emailAddress + '@gmail.com'
}


window.onload = function(){
	setSettingsForm()

	if(showSettings == true){
		displaySettings()
	}
	else {
		if(settings.authKey == ''){
			gData.login()
		} else {
			gData.viewFeeds()
		}
	}
}


/****************** Main Functions **********************/


function createSpreadsheetsHtml(array){
	var response = ['<ul>']
	
	var spreadsheet, lastUpdate
	
	array.sort(byUpdateTime)
	
	for(var i=0; i<array.length ; i++){
		spreadsheet = array[i]
		lastUpdate = new Date()
		lastUpdate.setISO8601(spreadsheet.updated)
		response.push('<li>')
		response.push('<h2><a href="' + spreadsheet.link + '" target="_blank">' + spreadsheet.title + '</a></h2>')
		response.push('Last Edited: ' + getRelativeTime(lastUpdate) )
		response.push('</li>')
	}
	if(array.length == 0){
		response.push('<li><b>No spreadsheets found</b></li>')
	}
	response.push('<\/ul>')
	
	document.getElementById('spreadsheets').innerHTML = response.join('')
}


function byUpdateTime(a,b){
	return b.updated < a.updated ? -1 : 1
}



/****************** Settings **********************/


function displaySettings(){
	document.getElementById('main').style.display = 'none'
	document.getElementById('settings').style.display = ''
	document.getElementById('links').style.display = 'none'
	document.getElementById('emailAddress').focus()
}


function hideSettings(){
	document.getElementById('main').style.display = ''
	document.getElementById('links').style.display = ''
	document.getElementById('settings').style.display = 'none'
}


function setSettingsForm(){
	document.getElementById('emailAddress').value = decodeURIComponent( settings.emailAddress )
	document.getElementById('password').value = decodeURIComponent( settings.password )
}


function cancelSettings(){
	hideSettings()
	
	if(settings.emailAddress == '' || settings.password == ''){
		var message = '<a href="javascript:displaySettings()">Login first!</a>'
		document.getElementById('data').innerHTML = message
	}
}


function saveSettings(){
	settings.emailAddress = encodeURIComponent( document.getElementById('emailAddress').value )
	settings.password = encodeURIComponent( document.getElementById('password').value )

	MaxLib.writeSetting('EmailAddress', encodeTxt( settings.emailAddress ))
	MaxLib.writeSetting('Password', encodeTxt( settings.password ))
	
	MaxLib.writeSetting('authKey', '')

	location.reload()
}

function enterKeyPressConfig() {
	if (window.event.keyCode == 13){
		saveSettings()
	}
}


/****************** Encryption **********************/

//Thanks to http://scriptasylum.com for the encoder/decoder!

function encodeTxt(s){
	s=escape(s);
	var ta=new Array();
	for(var i=0;i<s.length;i++){
		ta[i]=s.charCodeAt(i)+1;
	}
	return ""+escape(eval("String.fromCharCode("+ta+")"))+1;
}


function decodeTxt(s){
	var s1=unescape(s.substr(0,s.length-1));
	var t='';
	for(var i=0;i<s1.length;i++){
		t+=String.fromCharCode(s1.charCodeAt(i)-s.substr(s.length-1,1));
	}
	return unescape(t);
}


/****************** Date **********************/


Date.prototype.setISO8601 = function (string) {
    var regexp = "([0-9]{4})(-([0-9]{2})(-([0-9]{2})" +
        "(T([0-9]{2}):([0-9]{2})(:([0-9]{2})(\.([0-9]+))?)?" +
        "(Z|(([-+])([0-9]{2}):([0-9]{2})))?)?)?)?";
    var d = string.match(new RegExp(regexp));

    var offset = 0;
    var date = new Date(d[1], 0, 1);

    if (d[3]) { date.setMonth(d[3] - 1); }
    if (d[5]) { date.setDate(d[5]); }
    if (d[7]) { date.setHours(d[7]); }
    if (d[8]) { date.setMinutes(d[8]); }
    if (d[10]) { date.setSeconds(d[10]); }
    if (d[12]) { date.setMilliseconds(Number("0." + d[12]) * 1000); }
    if (d[14]) {
        offset = (Number(d[16]) * 60) + Number(d[17]);
        offset *= ((d[15] == '-') ? 1 : -1);
    }

    offset -= date.getTimezoneOffset();
    time = (Number(date) + (offset * 60 * 1000));
    this.setTime(Number(time));
}


function getRelativeTime(dateObj){
	var currentTime = new Date().getTime() / 1000
	var difference = currentTime - dateObj.getTime() / 1000
	var result
	if(difference < 3600){
		result = Math.round( difference / 60 ) + ' minutes'
	} else if(difference < 3600 * 24){
		result = Math.round( difference / 3600 ) + ' hours'
	} else {
		result = Math.round( difference / 3600 / 24 ) + ' days'
	}
	return result + ' ago'
}


/****************** Other **********************/


function loginToGoogleAccount(){
	var form = document.getElementById('form')
	form['continue'].value = 'http://docs.google.com/'
	form['service'].value = 'wise'
	form['Email'].value = settings.emailAddress
	form['Passwd'].value = settings.password
	form.submit()
}